@@ -1,6 +1,6 @@
 use 5.020;
 use warnings;
-package Plate 0.1;
+package Plate 0.2;
 
 use Carp 'croak';
 use File::Spec;
@@ -13,6 +13,8 @@ BEGIN {
     XSLoader::load __PACKAGE__, $Plate::VERSION;
 }
 
+=encoding UTF-8
+
 =head1 NAME
 
 Plate - Fast templating engine with support for embedded Perl
@@ -95,15 +97,15 @@ sub _parse {
     my $expr2stmt = sub {
         if (@expr) {
             if (defined $stmt) {
-                $stmt .= '$Plate::_b.=';
+                $stmt .= ';$Plate::_b.=';
             } else {
                 $stmt = 'local$Plate::_b=';
             }
-            $stmt .= join('.', $_[1] ? splice @expr, 0, $fix_line_num : splice @expr).';';
+            $stmt .= join('.', $_[0] ? splice @expr, 0, $fix_line_num : splice @expr).';';
         } else {
             $stmt //= q"local$Plate::_b='';";
         }
-        undef $fix_line_num unless $_[1];
+        undef $fix_line_num unless $_[0];
     };
     while ($_[0] =~ /$_[1]/g) {
 
@@ -118,19 +120,19 @@ sub _parse {
             ($pos, $line) = splice @Plate::_l, 0, 2 while @Plate::_l and $Plate::_l[0] <= $+[1];
             my $rem = $+[1] - $pos;
             $line += substr($_[0], $pos, $rem) =~ tr/\n// if $rem;
-            $expr2stmt->($_[1]);
+            $expr2stmt->();
             $stmt .= "\n#line $line\n";
         }
 
         if (defined $2) {
             # % ...
-            $expr2stmt->($_[1]);
+            $expr2stmt->();
             $stmt .= _parse_cmnt $2;
             $stmt .= "\n";
 
         } elsif (defined $3) {
             # <%perl>
-            $expr2stmt->($_[1]);
+            $expr2stmt->();
             unless (defined $4) {
                 my $line = 1 + $stmt =~ y/\n//;
                 $line = "$_[2] line $line.\nPlate ".($_[1] == $re_pre && 'pre').'compilation failed';
@@ -141,20 +143,20 @@ sub _parse {
 
         } elsif (defined $5) {
             # <%def ...>
-            $expr2stmt->($_[1]);
+            $expr2stmt->();
             local $_[3] = ($_[1] == $re_pre && '%').'%def';
             $stmt .= 'local$$Plate::_s{mem}{'._parse_defn($5)."}=\nsub{".&_parse.'};';
 
         } elsif (defined $6) {
             # <% ... %>
-            $expr2stmt->($_[1], 1) if $fix_line_num;
+            $expr2stmt->(1) if $fix_line_num;
             $fix_line_num = push @expr,
             _parse_fltr "do{$6}", $7 // $$Plate::_s{auto_filter};
 
         } elsif (defined $9) {
             # <& ... &> or <&| ... &>
             my($tmpl, $args) = do { $9 =~ /^([\w\/\.-]+)\s*(?:,\s*(.*))?$/ };
-            $expr2stmt->($_[1], 1) if $fix_line_num;
+            $expr2stmt->(1) if $fix_line_num;
             if (defined $tmpl) {
                 if ($tmpl eq '_') {
                     $fix_line_num = push @expr, _parse_fltr defined $8
@@ -185,7 +187,7 @@ sub _parse {
             }
 
             my $pl = defined $stmt
-            ? $stmt.join('.', '$Plate::_b', @expr)
+            ? $stmt.join('.', ';$Plate::_b', @expr)
             : @expr ? join('.', @expr) : "''";
             $pl .= '=~s/\R\z//r' if $_[1] == $re_run and $$Plate::_s{chomp};
             $pl .= "\n" if defined $11;
@@ -193,7 +195,7 @@ sub _parse {
         }
 
         if ($_[1] == $re_pre) {
-            $expr2stmt->($_[1]);
+            $expr2stmt->();
             $stmt .= 'push@Plate::_l,length$Plate::_b,__LINE__;';
 
         } elsif (@Plate::_l and $Plate::_l[0] <= $+[0]) {
@@ -201,7 +203,7 @@ sub _parse {
             ($pos, $line) = splice @Plate::_l, 0, 2 while @Plate::_l and $Plate::_l[0] <= $+[0];
             my $rem = $+[0] - $pos;
             $line += substr($_[0], $pos, $rem) =~ tr/\n// if $rem;
-            $expr2stmt->($_[1]);
+            $expr2stmt->();
             $stmt .= "\n#line $line\n";
         }
     }
@@ -342,6 +344,133 @@ sub _path {
     sub _basic_html_filter { $_[0] =~ s/(["&'<>])/$esc_html{$1}/egr }
 }
 
+=head1 DESCRIPTION
+
+Plate is a very fast, efficient and full-featured templating engine.
+
+Inspired by L<HTML::Mason> and L<Tenjin>, the goal of this templating engine is speed and functionality.
+It has no non-core dependencies, is a compact size and supports embedded Perl.
+
+Features include preprocessing templates,
+caching compiled templates,
+variable escaping/filtering,
+localised global variables.
+Templates can also include other templates, with optional content
+and even define or override templates locally.
+
+All templates have strict, warnings, utf8 and Perl 5.20 features enabled.
+
+=head2 Example
+
+Here is an example template for a letter stored in the file: C<letter.plate>
+
+    % my($title, $surname) = @_;
+    Dear <% $title %> <% $surname %>,
+    
+    <& _ &>
+    
+        Kind Regards,
+    
+        E. X. Ample
+
+Another template could I<include> this template, Eg: C<job.plate>
+
+    <&| letter, 'Dr.', 'No' &>\
+    In response to the recently advertised position, please
+    consider my résumé in your search for a professional sidekick.
+    </&>
+
+Serving the C<job.plate> template will result in the following output:
+
+    Dear Dr. No,
+    
+    In response to the recent advertised position, please
+    consider my résumé in your search for a professional sidekick.
+    
+            Kind Regards,
+    
+            E. X. Ample
+
+Here is the code to render this output:
+
+    use Plate;
+    
+    my $plate = new Plate;
+    my $output = $plate->serve('job');
+
+=head2 Markup
+
+=head3 Variables
+
+    <% $var %>
+    <% $unescaped |%>
+    <% $filtered |trim |html %>
+
+Variables are interpolated into the output and optionally filtered (escaped).
+Filters are listed in the order to be applied preceded by a C<|> character.
+If no filter is given as in the first example, then the default filter is applied.
+To explicitly avoid the default filter use the empty string as a filter.
+
+=head3 Statements
+
+    % my $user = db_lookup(user => 'bob');
+    % for my $var (@list) {
+
+Lines that start with a C<%> character are treated as Perl statements.
+
+=head3 Perl blocks
+
+    <%perl>
+    ...
+    </%perl>
+
+Perl code can also be wrapped in a perl block.
+
+=head3 Newlines
+
+Newline characters can be escaped with a backslash, Eg:
+
+    % for my $var ('a' .. 'c') {
+    <% $var %>\
+    % }
+
+This will result in the output C<abc>, all on one line.
+
+=head3 Content
+
+    <& _ &>
+
+A template can be served with content. This markup will insert the content provided, if any.
+
+=head3 Include other templates
+
+    <& header, 'My Title' &>
+    ...
+    <& footer &>
+
+A template can include other templates with optional arguments.
+
+=head3 Include other templates with provided content
+
+    <&| paragraph &>
+    This content is passed to the "paragraph" template.
+    </&>
+    
+    Plain text, <&| bold &>bold text</&>, plain text.
+
+An included template can have its own content passed in.
+
+=head3 Def blocks
+
+    <%def copyright>
+    Copyright © <% $_[0] %>
+    </%def>
+    
+    <& copyright, 2018 &>
+
+Local templates can be defined in a template.
+They can even override existing templates.
+
 =head1 SUBROUTINES/METHODS
 
 =head2 new
@@ -490,10 +619,14 @@ sub serve_with {
 
 =head2 content
 
+    % my $content = &Plate::content;
+
 Used from within a template to return the content passed to that template.
 
 =head2 has_content
 
+    % if (Plate::has_content) { ...
+
 Used from within a template to determine if that template was called with content.
 
 =cut
@@ -566,6 +699,9 @@ sub var {
 This will cache a template in memory.
 The C<$content> is the contents of a template (as a string) to be compiled or a CODE ref.
 
+This is useful if you need to use templates that are not stored on the file system,
+for example from a database or a custom subroutine.
+
 =head2 undefine
 
     $plate->undefine;
